---
slug: /api-overview
---

# API Reference

seekdb allows you to use seekdb through APIs.

## APIs

The following APIs are supported.

### Database

:::info
You can use this API only when you connect to seekdb by using the `AdminClient`. For more information about the `AdminClient`, see [Admin Client](../50.apis/100.admin-client.md).
:::

| API | Description | Documentation |
|---|---|---|
| `create_database()` | Creates a database. | [Documentation](110.database/200.create-database-of-api.md) |
| `get_database()` | Retrieves a specified database. |[Documentation](110.database/300.get-database-of-api.md)|
| `list_databases()`  | Retrieves a list of databases in an instance.  |[Documentation](110.database/400.list-database-of-api.md)|
| `delete_database()`  | Deletes a specified database.|[Documentation](110.database/500.delete-database-of-api.md)|


### Collection

:::info
You can use this API only when you connect to seekdb by using the `Client`. For more information about the `Client`, see [Client](../50.apis/50.client.md).
:::

| API | Description | Documentation |
|---|---|---|
| `create_collection()` | Creates a collection. | [Documentation](200.collection/100.create-collection-of-api.md) |
| `get_collection()` | Retrieves a specified collection. |[Documentation](200.collection/200.get-collection-of-api.md)|
| `get_or_create_collection()` | Creates or queries a collection. If the collection does not exist in the database, it is created. If the collection exists, the corresponding result is obtained. |[Documentation](200.collection/250.get-or-create-collection-of-api.md)|
| `list_collections()`  | Retrieves the collection list in a database.  |[Documentation](200.collection/300.list-collection-of-api.md)|
| `count_collection()`  | Counts the number of collections in a database.  |[Documentation](200.collection/350.count-collection-of-api.md)|
| `delete_collection()`  | Deletes a specified collection.|[Documentation](200.collection/400.delete-collection-of-api.md)|


### DML

:::info
You can use this API only when you connect to seekdb by using the `Client`. For more information about the `Client`, see [Client](../50.apis/50.client.md).
:::

| API | Description | Documentation |
|---|---|---|
| `add()` | Inserts a new record into a collection. | [Documentation](300.dml/200.add-data-of-api.md) |
| `update()` | Updates an existing record in a collection. |[Documentation](300.dml/300.update-data-of-api.md)|
| `upsert()`  | Inserts a new record or updates an existing record.  |[Documentation](300.dml/400.upsert-data-of-api.md)|
| `delete()`  | Deletes a record from a collection.|[Documentation](300.dml/500.delete-data-of-api.md)|

### DQL

:::info
You can use this API only when you connect to seekdb by using the `Client`. For more information about the `Client`, see [Client](../50.apis/50.client.md).
:::

| API | Description | Documentation |
|---|---|---|
| `query()` | Performs vector similarity search. | [Documentation](400.dql/200.query-interfaces-of-api.md) |
| `get()` | Queries specific data from a table by using the ID, document, and metadata (non-vector). |[Documentation](400.dql/300.get-interfaces-of-api.md)|
| `hybrid_search()`  | Performs full-text search and vector similarity search by using ranking.  |[Documentation](400.dql/400.hybrid-search-of-api.md)|
